@@ -1,6 +1,6 @@
 (* hey emacs, this is OCaml code: -*- tuareg -*- *)
 (* nbd client library in userspace: generate the code for the state machine
- * Copyright (C) 2013-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -298,7 +298,9 @@ let generate_lib_states_h () =
   pr "enum state {\n";
   List.iter (
     fun ({ comment; parsed = { display_name; state_enum } }) ->
-      pr "  /* %s: %s */\n" display_name comment;
+      pr "  ";
+      pr_wrap_c_comment (fun () -> pr "%s: %s" display_name comment);
+      pr "\n";
       pr "  %s,\n" state_enum;
       pr "\n";
   ) states;
@@ -331,7 +333,9 @@ let generate_lib_states_h () =
   pr "/* State transitions defined in states.c. */\n";
   List.iter (
     fun { parsed = { state_enum } } ->
-      pr "extern int nbd_internal_enter_%s (struct nbd_handle *h, bool *blocked);\n" state_enum;
+      pr "extern int nbd_internal_enter_%s (\n" state_enum;
+      pr "             struct nbd_handle *h, bool *blocked\n";
+      pr "           );\n"
   ) states
 
 let generate_lib_states_c () =
@@ -346,11 +350,12 @@ let generate_lib_states_c () =
   List.iter (
     fun { comment; parsed = { display_name; state_enum; loc; code } } ->
       pr "\n";
-      pr "/* %s: %s */\n" display_name comment;
+      pr_wrap_c_comment (fun () -> pr "%s: %s" display_name comment);
+      pr "\n";
       pr "static int\n";
-      pr "enter_%s (struct nbd_handle *h,\n" state_enum;
-      pr "             enum state *next_state,\n";
-      pr "             bool *blocked)\n";
+      pr "enter_%s (\n" state_enum;
+      pr "  struct nbd_handle *h, enum state *next_state, bool *blocked\n";
+      pr ")\n";
       pr "{\n";
       if code <> "" then (
         pr "%s\n" (line_directive_of_location loc);
@@ -363,18 +368,22 @@ let generate_lib_states_c () =
       let output_loc = "lib/states.c", output_lineno () + 1 in
       pr "%s\n" (line_directive_of_location output_loc);
       pr "int\n";
-      pr "nbd_internal_enter_%s (struct nbd_handle *h, bool *blocked)\n"
-        state_enum;
+      pr "nbd_internal_enter_%s (\n" state_enum;
+      pr "  struct nbd_handle *h, bool *blocked\n";
+      pr ")\n";
       pr "{\n";
       pr "  int r;\n";
-      pr "  enum state next_state = %s;\n" state_enum;
+      pr "  enum state next;\n";
       pr "\n";
-      pr "  r = enter_%s (h, &next_state, blocked);\n" state_enum;
-      pr "  if (get_next_state (h) != next_state) {\n";
+      pr "  next = %s;\n" state_enum;
+      pr "  r = enter_%s (\n" state_enum;
+      pr "        h, &next, blocked\n";
+      pr "      );\n";
+      pr "  if (get_next_state (h) != next) {\n";
       pr "    debug (h, \"transition: %%s -> %%s\",\n";
       pr "           \"%s\",\n" display_name;
-      pr "           nbd_internal_state_short_string (next_state));\n";
-      pr "    set_next_state (h, next_state);\n";
+      pr "           nbd_internal_state_short_string (next));\n";
+      pr "    set_next_state (h, next);\n";
       pr "  }\n";
       pr "  return r;\n";
       pr "}\n";
@@ -414,10 +423,15 @@ let generate_lib_states_run_c () =
             pr "    case %s:\n" (c_string_of_external_event e);
             if state != next_state then (
               pr "      set_next_state (h, %s);\n" next_state.parsed.state_enum;
-              pr "      debug (h, \"event %%s: %%s -> %%s\",\n";
-              pr "             \"%s\", \"%s\", \"%s\");\n"
-                 (string_of_external_event e)
-                 display_name next_state.parsed.display_name;
+              pr "      debug (";
+              let print_debug_args () =
+                pr "h, \"event %%s: %%s -> %%s\", ";
+                pr "\"%s\", \"%s\", \"%s\");"
+                   (string_of_external_event e)
+                   display_name next_state.parsed.display_name;
+              in
+              pr_wrap ',' print_debug_args;
+              pr "\n"
             );
             pr "      goto ok;\n";
         ) events;
